@@ -3,12 +3,11 @@ Structure for boto3-stubs module.
 """
 
 from collections.abc import Iterable
+from typing import Type
 
-from boto3 import __version__ as boto3_version
-
-from mypy_boto3_builder.constants import BOTO3_STUBS_NAME
 from mypy_boto3_builder.import_helpers.import_record import ImportRecord
 from mypy_boto3_builder.import_helpers.import_string import ImportString
+from mypy_boto3_builder.package_data import BasePackageData
 from mypy_boto3_builder.service_name import ServiceName
 from mypy_boto3_builder.structures.class_record import ClassRecord
 from mypy_boto3_builder.structures.function import Function
@@ -24,18 +23,17 @@ class Boto3StubsPackage(Package):
 
     def __init__(
         self,
+        data: Type[BasePackageData],
         session_class: ClassRecord | None = None,
         service_names: Iterable[ServiceName] = tuple(),
         service_packages: Iterable[ServicePackage] = tuple(),
         init_functions: Iterable[Function] = tuple(),
     ):
-        super().__init__(name=BOTO3_STUBS_NAME, pypi_name=BOTO3_STUBS_NAME)
+        super().__init__(data)
         self.session_class = session_class or ClassRecord("Session")
         self.service_names = list(service_names)
         self.service_packages = list(service_packages)
         self.init_functions = list(init_functions)
-        self.library_name = "boto3"
-        self.library_version = boto3_version
 
     @property
     def essential_service_names(self) -> list[ServiceName]:
